﻿/*  ----------------------------------------------------------------------------
 *  WestLaw Business
 *  ----------------------------------------------------------------------------
 *  Copyright 2011 Thomson Reuters Global Resources.  All Rights Reserved.
 *  Proprietary and Confidential information of TRGR.
 *  Disclosure, Use, or Reproduction without the written authorization of TRGR is prohibited.
 *  ----------------------------------------------------------------------------
 *  Author:     TLR\C105578 (Jim Sugrue)
 *  ----------------------------------------------------------------------------
 */
namespace TRGR.WLB.UE.UI.Modules.Maintenance
{
    using Microsoft.Practices.Prism.Modularity;
    using Microsoft.Practices.Prism.Regions;
    using Microsoft.Practices.Unity;

    using TRGR.WLB.UE.Common.Infrastructure;
    using TRGR.WLB.UE.UI.Modules.ContextMaintenanceSettings;
    using TRGR.WLB.UE.UI.Modules.DocumentMaintenanceSettings;
    using TRGR.WLB.UE.UI.Modules.RoleMaintenanceSettings;
    using TRGR.WLB.UE.UI.Modules.UnitMaintenanceSettings;

    /// <summary>
    /// Module which controls the creation of the Maintenance View and its registration with the Prism Region Manager  
    /// </summary>
    public class MaintenanceModule : IModule
    {
        /// <summary>
        /// Reference to the Unity Container
        /// </summary>
        private readonly IUnityContainer container;

        /// <summary>
        /// Reference to the Prism RegionManager
        /// </summary>
        private readonly IRegionManager regionManager;

        /// <summary>
        /// Initializes a new instance of the MaintenanceModule class
        /// The constructor requires references to the Unity Container and the Prism Region Manager to be provided via dependency injection
        /// </summary>
        /// <param name="container">Reference to the Unity Container</param>
        /// <param name="regionManager">Reference to the Prism Region Manager</param>
        public MaintenanceModule(IUnityContainer container, IRegionManager regionManager)
        {
            this.container = container;
            this.regionManager = regionManager;
        }

        /// <summary>
        /// Initialization method called when the module is registered with the Prism catalog.  It uses the Unity Container to create the view and resolve its dependencies.
        /// It then registers the view with the Prism Region Manager
        /// </summary>
        public void Initialize()
        {
            // Maintenance View
            var maintenanceView = this.container.Resolve<MaintenanceView>();
            this.regionManager.RegisterViewWithRegion(Constants.MaintenanceViewRegion, () => maintenanceView);

            // ContextMaintenanceSettingsView
            var contextMaintenanceSettingsView = this.container.Resolve<ContextMaintenanceSettingsView>();
            this.regionManager.RegisterViewWithRegion("ContextMaintenanceRegion", () => contextMaintenanceSettingsView);

            // DocumentMaintenanceSettingsView
            var documentMaintenanceSettingsView = this.container.Resolve<DocumentMaintenanceSettingsView>();
            this.regionManager.RegisterViewWithRegion("DocumentMaintenanceRegion", () => documentMaintenanceSettingsView);

            // RoleMaintenanceSettingsView
            var roleMaintenanceSettingsView = this.container.Resolve<RoleMaintenanceSettingsView>();
            this.regionManager.RegisterViewWithRegion("RoleMaintenanceRegion", () => roleMaintenanceSettingsView);

            // UnitMaintenanceSettingsView
            var unitMaintenanceSettingsView = this.container.Resolve<UnitMaintenanceSettingsView>();
            this.regionManager.RegisterViewWithRegion("UnitMaintenanceRegion", () => unitMaintenanceSettingsView);
        }
    }
}
